var FormFactorTable_8h =
[
    [ "FormFactorTable", "classIMP_1_1saxs_1_1FormFactorTable.html", "classIMP_1_1saxs_1_1FormFactorTable" ],
    [ "FormFactorType", "FormFactorTable_8h.html#af6bcf28f95539cc1cfa91071938ee111", [
      [ "ALL_ATOMS", "FormFactorTable_8h.html#af6bcf28f95539cc1cfa91071938ee111a2c0285d34a640e5d72735b68ddc1e7e4", null ],
      [ "HEAVY_ATOMS", "FormFactorTable_8h.html#af6bcf28f95539cc1cfa91071938ee111a3e78408c5da97f92f0320182842ca34b", null ],
      [ "CA_ATOMS", "FormFactorTable_8h.html#af6bcf28f95539cc1cfa91071938ee111a77196265475c28f29ac633cce99e4c1a", null ]
    ] ],
    [ "get_default_form_factor_table", "FormFactorTable_8h.html#a4376a2c676c4c92975cbb4df0cb6d294", null ]
];